<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_404_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_404';
	}

	public function get_title() {
		return __( '404', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', '404' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'text',
            [
                'label' => esc_html__('Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('We Help Students to Pass <br>Test & Get a License on the <br>First Try', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Ready to Learn Driving?', 'drvngsupport'),
            ]
        );
        
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'title_class',
            [
                'label' => esc_html__('Title Class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'button_title',
            [
                'label' => esc_html__('Button Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );

        $this->end_controls_section();

        

	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $text = $settings["text"];
        $title_class = $settings["title_class"];
        $button_title = $settings["button_title"];
        $button_link = $settings["button_link"]["url"];
        $button_link_external = $settings["button_link"]["is_external"] ? 'target="_blank"' : '';
        $button_link_nofollow = $settings["button_link"]["nofollow"] ? 'rel="nofollow"' : '';

?>
       
       <section class="error-section">
        <div class="auto-container">
            <div class="content">
                <h1><?php echo $title; ?></h1>
                <h2><?php echo $sub_title; ?></h2>
                <div class="text"><?php echo $text; ?></div>
                <a href="<?php echo esc_url($button_link); ?>" <?php echo $button_link_external; ?> <?php echo $button_link_nofollow; ?> class="theme-btn btn-style-one"><span> <?php echo $button_title; ?></span></a>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_404_Widget() );