<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_about_two_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_about_two';
	}

	public function get_title() {
		return __( 'About Two', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'slider' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );


        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description Text', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => esc_html__('List', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_icon',
            [
                'label' => esc_html__('Phone Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

        $this->add_control(
            'phone_number_title',
            [
                'label' => esc_html__('Phone Number Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Have Questions?', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__('Phone Number', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('+ 1- (246) 333-0089', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number_tel',
            [
                'label' => esc_html__('Phone Number Tel', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('tel:+1(246)3330089', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'author_thumb',
            [
                'label' => esc_html__('Author Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'signature',
            [
                'label' => esc_html__('Author Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $heading = $settings['heading'];
        $sub_heading = $settings['sub_heading'];
        $description = $settings['description'];
        $list = $settings['list'];
        $phone_icon = $settings['phone_icon'];
        $phone_number_title = $settings['phone_number_title'];
        $phone_number = $settings['phone_number'];
        $phone_number_tel = $settings['phone_number_tel'];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
        $author_thumb = ($settings["author_thumb"]["id"] != "") ? wp_get_attachment_image_url($settings["author_thumb"]["id"], "full") : $settings["author_thumb"]["url"];
        $author_thumb_alt = get_post_meta($settings["author_thumb"]["id"], "_wp_attachment_image_alt", true);
        $signature = ($settings["signature"]["id"] != "") ? wp_get_attachment_image_url($settings["signature"]["id"], "full") : $settings["signature"]["url"];
        $signature_thumb_alt = get_post_meta($settings["signature"]["id"], "_wp_attachment_image_alt", true);
?>

    <!-- Introduction Section -->
    <section class="introduction-section">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6">
                    <div class="image">
                        <div class="img_hover_3">
                        <?php
                            if (wp_http_validate_url($image)) {
                            ?>
                                <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                            <?php
                            } else {
                                echo $image;
                        }
                        ?>
                        </div>
                    </div>
                </div>
                <div class="col-lg-6">
                    <div class="sec-title mb-30">
                        <h4><?php echo $sub_heading; ?></h4>
                        <h2><?php echo $heading; ?></h2>
                    </div>
                    <div class="text mb-30"><?php echo $description; ?></div>
                    <div class="row">
                        <div class="col-md-7">
                            <div class="ul">
                                <?php echo $list; ?>
                            </div>
                            <div class="image-wrapper">
                                <div class="image-two">
                                <?php
                                    if (wp_http_validate_url($author_thumb)) {
                                    ?>
                                        <img src="<?php echo esc_url($author_thumb); ?>" alt="<?php esc_url($author_thumb_alt); ?>">
                                    <?php
                                    } else {
                                        echo $author_thumb;
                                }
                                ?>
                                </div>
                                <div class="signature">
                                <?php
                                    if (wp_http_validate_url($signature)) {
                                    ?>
                                        <img src="<?php echo esc_url($signature); ?>" alt="<?php esc_url($signature_alt); ?>">
                                    <?php
                                    } else {
                                        echo $signature;
                                }
                                ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-5">
                            <div class="text-box">
                                <div class="icon"><i class="<?php echo $phone_icon['value']; ?>"></i></div>
                                <div class="text-two"><?php echo $phone_number_title; ?></div>
                                <a href="<?php echo $phone_number_tel; ?>"><?php echo $phone_number; ?></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_about_two_Widget() );