<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_about_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_about';
	}

	public function get_title() {
		return __( 'About', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'slider' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'heading',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Schedule Your Driving <br>
                Lessons with Us', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Our Introduction', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'text',
            [
                'label' => esc_html__('Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Vestibulum odio nisl, euismod sed elit sed, sagittis laoreet lacus.', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description Text', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number_title',
            [
                'label' => esc_html__('Phone Number Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Have Questions?', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__('Phone Number', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('+ 1- (246) 333-0089', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number_tel',
            [
                'label' => esc_html__('Phone Number Tel', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('tel:+1(246)3330089', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image_box_image',
            [
                'label' => esc_html__('Image Box Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image_box_text',
            [
                'label' => esc_html__('Image Box Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('More than <br>
                8,800 license <br>
                issued', 'drvngsupport'),
            ]
        );



        $this->end_controls_section();
		$this->start_controls_section(
			'Icon Box',
			[
				'label' => __( 'Icon Box', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();


		$repeater->add_control(
            'icon_box_text',
            [
                'label' => esc_html__('Icon Box Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Online Traffic <br> School', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'icon_box_icon',
            [
                'label' => esc_html__('Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $heading = $settings['heading'];
        $sub_heading = $settings['sub_heading'];
        $text = $settings['text'];
        $description = $settings['description'];
        $phone_number_title = $settings['phone_number_title'];
        $phone_number = $settings['phone_number'];
        $phone_number_tel = $settings['phone_number_tel'];
        $image_box_text = $settings['image_box_text'];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
        $image_box_image = ($settings["image_box_image"]["id"] != "") ? wp_get_attachment_image_url($settings["image_box_image"]["id"], "full") : $settings["image_box_image"]["url"];
        $image_box_image_alt = get_post_meta($settings["image_box_image"]["id"], "_wp_attachment_image_alt", true);
?>


    <!-- About section -->
    <section class="about-section">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6 pe-lg-5">
                    <div class="sec-title">
                        <h4><?php echo $sub_heading; ?></h4>
                        <h2><?php echo $heading; ?></h2>
                    </div>
                    <h3><?php echo $text; ?></h3>
                    <div class="text">
                    <?php echo $description; ?></div>
                    <div class="row">
                    <?php
                        $i = 1;
                        foreach ($settings["items"] as $item) {
                            $icon_box_text = $item["icon_box_text"];
                            $icon_box_icon = $item["icon_box_icon"];
                        ?>
                        <div class="col-md-6">
                            <div class="icon_box wow fadeInUp" data-wow-duration="1500ms">
                                <i class="<?php echo $icon_box_icon['value']; ?>"></i>
                                <h4><?php echo $icon_box_text; ?></h4>
                            </div>
                        </div>
                        <?php $i++;
                        } ?>
                    </div>
                    <div class="phone-number"><?php echo $phone_number_title; ?>   <a href="<?php echo $phone_tel; ?>"><?php echo $phone_number; ?></a></div>
                </div>
                <div class="col-lg-6">
                    <div class="image">
                        <div class="img_hover_3 wow fadeInRight" data-wow-duration="1500ms">
                            <?php
                            if (wp_http_validate_url($image)) {
                            ?>
                                <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                            <?php
                            } else {
                                echo $image;
                            }
                            ?>
                        </div>                        
                        <div class="image_box" data-parallax='{"y": 40}'>
                            <?php
                            if (wp_http_validate_url($image_box_image)) {
                            ?>
                                <img src="<?php echo esc_url($image_box_image); ?>" alt="<?php esc_url($image_box_image_alt); ?>">
                            <?php
                            } else {
                                echo $image_box_image;
                            }
                            ?>
                            <h4><?php echo $image_box_text; ?></h4>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_about_Widget() );