<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_appointment_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_appointment';
	}

	public function get_title() {
		return __( 'Appointment', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'appointment' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Book Appointment & <br> Start Learning', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Fill to Form', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description', 'drvngsupport'),
            ]
        );
        
        $this->add_control(
            'video_icon',
            [
                'label' => esc_html__('Video Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

        $this->add_control(
            'video_url',
            [
                'label' => esc_html__('Video URL', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );

        $this->add_control(
            'form_shortcode',
            [
                'label' => esc_html__('Form Shortcode', 'drvngsupport'),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 6,
                'default' => __('', 'drvngsupport'),
                'placeholder' => esc_html__('Type your description here', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        

        $this->end_controls_section();

        $this->start_controls_section(
			'icon_box',
			[
				'label' => __( 'Icon Box', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'icon_box_title',
            [
                'label' => esc_html__('Icon Box Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Expert
                Instructors', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'icon_box_icon',
            [
                'label' => esc_html__('Icon Box Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $description = $settings["description"];
        $video_icon = $settings["video_icon"];
        $video_url = $settings["video_url"]["url"];
        $form_shortcode = $settings["form_shortcode"];
        $bg_image = ($settings["bg_image"]["id"] != "") ? wp_get_attachment_image_url($settings["bg_image"]["id"], "full") : $settings["bg_image"]["url"];

?>
       
    <!-- Appointment Section -->
    <section class="appointment-section" style="background-image: url(<?php echo $bg_image; ?>)">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6">
                    <div class="sec-title light">
                        <h4><?php echo $sub_title; ?></h4>
                        <h2><?php echo $title; ?></h2>
                    </div>
                    <div class="text"><?php echo $description; ?></div>
                    <div class="row">
                        <?php
                        $i = 1;
                        foreach ($settings["items"] as $item) {
                            $icon_box_icon = $item["icon_box_icon"];
                            $icon_box_title = $item["icon_box_title"];
                        ?>
                        <div class="col-md-6">
                            <div class="icon_box wow fadeInUp" data-wow-duration="1500ms">
                                <div class="icon"><i class="<?php echo $icon_box_icon['value']; ?>"></i></div>
                                <h4><?php echo $icon_box_title; ?></h4>
                            </div>
                        </div>
                        <?php $i++;
                        } ?>
                    </div>
                </div>      
                
                <div class="col-lg-6">
                    <!--Contact Form-->
                    <div class="contact-form">
                        <?php echo do_shortcode($form_shortcode); ?>
                        
                        <div class="video-box-two wow fadeInLeft" data-wow-duration="1500ms"><div class="video-btn"><a href="<?php echo $video_url; ?>" class="overlay-link play-now ripple" data-fancybox="gallery" data-caption=""><i class="<?php echo $video_icon['value']; ?>"></i></a></div></div>
                    </div>
                </div>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_appointment_Widget() );