<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_contact_info_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_contact_info';
	}

	public function get_title() {
		return __( 'Contact info', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'contact_info' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'bottom_text',
            [
                'label' => esc_html__('Bottom Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'social_links',
            [
                'label' => esc_html__('Social Links', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );
        

        $this->end_controls_section();

        $this->start_controls_section(
			'contact_info',
			[
				'label' => __( 'Contact info', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'label',
            [
                'label' => esc_html__('Label', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

		$repeater->add_control(
            'text',
            [
                'label' => esc_html__('Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $bottom_text = $settings["bottom_text"];
        $social_links = $settings["social_links"];
?>
       


    <!-- Contact info Section -->
    <section class="contact-info-section pt-0">
        <div class="auto-container">
            <div class="row">
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $label = $item["label"];
                    $text = $item["text"];
                    $icon = $item["icon"];
                ?>
                <div class="col-lg-4 icon_box">
                    <div class="inner-box">
                        <div class="icon"><i class="<?php echo $icon['value']; ?>"></i></div>
                        <div class="text"><?php echo $label; ?></div>
                        <h4><?php echo $text; ?></h4>
                    </div>
                </div>
                <?php $i++;
                } ?>
            </div>
            <div class="bottom-content text-center">
                <h3><?php echo $bottom_text; ?></span></h3>
                <ul class="social-links">
                    <?php echo $social_links; ?>
                </ul>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_contact_info_Widget() );