<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_contact_widget_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_contact_widget';
	}

	public function get_title() {
		return __( 'Contact Widget', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'contact_widget' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'phone_icon',
            [
                'label' => esc_html__('Phone Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

        $this->add_control(
            'phone_title',
            [
                'label' => esc_html__('Phone Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_tel',
            [
                'label' => esc_html__('Phone Tel', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__('Phone Number', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();

       
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $phone_icon = $settings["phone_icon"];
        $phone_title = $settings["phone_title"];
        $phone_tel = $settings["phone_tel"];
        $phone_number = $settings["phone_number"];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
?>
       


        <div class="contact-widget-two">
            <div class="image">
                <?php
                if (wp_http_validate_url($image)) {
                ?>
                    <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                <?php
                } else {
                    echo $image;
                }
                ?>
            </div>
            <div class="content">
                <div class="icon"><i class="<?php echo $phone_icon['value']; ?>"></i></div>
                <h5><?php echo $phone_title; ?></h5>
                <div class="phone-number">
                    <a href="<?php echo $phone_tel; ?>"><?php echo $phone_number; ?></a>
                </div>
            </div>
        </div>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_contact_widget_Widget() );