<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_course_category_widget_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_course_category_widget';
	}

	public function get_title() {
		return __( 'Course category', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'course_category_widget' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {

        $this->start_controls_section(
			'course_category_widget',
			[
				'label' => __( 'Course category', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
        
        $this->add_control(
            'widget_title',
            [
                'label' => esc_html__('Widget Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater = new Repeater();

		
		$repeater->add_control(
            'title',
            [
                'label' => esc_html__('Course Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'title_link',
            [
                'label' => esc_html__('Title Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );

        $repeater->add_control(
            'active_status',
            [
                'label' => esc_html__('Active Status', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $widget_title = $settings["widget_title"];
?>
       


        <div class="service-widget">
            <h4 class="widget-title"><?php echo $widget_title; ?></h4>
            <ul>
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $title = $item["title"];
                    $active_status = $item["active_status"];
                    $title_link = $item["title_link"]["url"];
                    $title_link_external = $item["title_link"]["is_external"] ? 'target="_blank"' : '';
                    $title_link_nofollow = $item["title_link"]["nofollow"] ? 'rel="nofollow"' : '';
                ?>
                    <li class="<?php echo $active_status; ?>"><a href="<?php echo esc_url($title_link); ?>" <?php echo $title_link_external; ?> <?php echo $title_link_nofollow; ?>><?php echo $title; ?></a></li>

                <?php $i++;
                } ?>
            </ul>
        </div>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_course_category_widget_Widget() );