<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_course_details_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_course_details';
	}

	public function get_title() {
		return __( 'Course details', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'course_details' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );        

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'text_block',
			[
				'label' => __( 'Text Block', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'title_two',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'description_two',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'count',
            [
                'label' => esc_html__('Count', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
			'image_block',
			[
				'label' => __( 'Image Block', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'image_two',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );        

        $this->add_control(
            'title_three',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'text',
            [
                'label' => esc_html__('Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => esc_html__('List', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $title_three = $settings["title_three"];
        $text = $settings["text"];
        $description = $settings["description"];
        $list = $settings["list"];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
        $image_two = ($settings["image_two"]["id"] != "") ? wp_get_attachment_image_url($settings["image_two"]["id"], "full") : $settings["image_two"]["url"];
        $image_two_alt = get_post_meta($settings["image_two"]["id"], "_wp_attachment_image_alt", true);

?>
       


       <div class="course-details">
            <div class="image">
                <?php
                if (wp_http_validate_url($image)) {
                ?>
                    <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                <?php
                } else {
                    echo $image;
                }
                ?>
            </div>
            <h2><?php echo $title; ?></h2>
            <div class="text">
                <p><?php echo $description; ?></p>
            </div>
            <div class="row">
                <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $title_two = $item["title_two"];
                    $description_two = $item["description_two"];
                    $count = $item["count"];
                ?>
                <div class="col-md-6">
                    <div class="text-block"> 
                        <h4><span><?php echo $count; ?></span> <?php echo $title_two; ?></h4>
                        <div class="text-two"><?php echo $description_two; ?></div>
                    </div>
                </div>
                <?php $i++;
                } ?>
                
            </div>
            <div class="border-bottom mt-30 mb-50"></div>
            <div class="row mb-40">
                <div class="col-md-6">
                    <div class="text-block-two">
                        <h4><?php echo $title_three; ?></h4>
                        <div class="text-three"><?php echo $text; ?></div>
                        <ul>
                            <?php echo $list; ?>
                        </ul>
                    </div>
                </div>
                <div class="col-md-6">
                    <div class="image">
                    <?php
                        if (wp_http_validate_url($image_two)) {
                        ?>
                            <img src="<?php echo esc_url($image_two); ?>" alt="<?php esc_url($image_two_alt); ?>">
                        <?php
                        } else {
                            echo $image_two;
                        }
                    ?>
                    </div>
                </div>
            </div>
        </div>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_course_details_Widget() );