<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_courses_two_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_courses_two';
	}

	public function get_title() {
		return __( 'Courses_two', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'courses_two' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		

        $this->start_controls_section(
			'courses_two',
			[
				'label' => __( 'Courses', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

		$repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();
?>
       
    
    <!-- Courses Section two -->
    <section class="courses-section-two pt-0">
        <div class="auto-container">
            <div class="row">
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $title = $item["title"];
                    $description = $item["description"];
                    $image = ($item["image"]["id"] != "") ? wp_get_attachment_image_url($item["image"]["id"], "full") : $item["image"]["url"];
                    $image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                ?>
                <div class="col-lg-6 course-block-two">
                    <div class="inner-box wow fadeInUp" data-wow-duration="1500ms">
                        <div class="image">
                        <?php
                            if (wp_http_validate_url($image)) {
                            ?>
                                <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                            <?php
                            } else {
                                echo $image;
                            }
                            ?>
                        </div>
                        <div class="lower-content">
                            <h4><?php echo $title; ?></h4>
                            <div class="text"><?php echo $description; ?></div>
                        </div>
                    </div>
                </div>
                <?php $i++;
                } ?>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_courses_two_Widget() );