<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_courses_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_courses';
	}

	public function get_title() {
		return __( 'Courses', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'courses' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'section_class',
            [
                'label' => esc_html__('Section Class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
			'title_alignment',
			[
				'label' => __( 'Title Alignment', 'drvngsupport' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'Default',
				'options' => [
					'default'  => __( 'Left', 'drvngsupport' ),
                    'text-center' => __( 'Center', 'drvngsupport' ),
                    'text-right' => __( 'right', 'drvngsupport' ),
				],
			]
		);

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'drvngsupport' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'Default',
				'options' => [
					'dark'  => __( 'Dark', 'drvngsupport' ),
                    'light' => __( 'Light', 'drvngsupport' ),
				],
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Our Driving Courses', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Courses We’re Offering', 'drvngsupport'),
            ]
        );
        

        $this->end_controls_section();

        $this->start_controls_section(
			'courses',
			[
				'label' => __( 'Courses', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'thumb',
            [
                'label' => esc_html__('Thumb', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

		$repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Kevin Martin', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'designation',
            [
                'label' => esc_html__('Designation', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Instructor', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'course_title',
            [
                'label' => esc_html__('Course Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Highway <br>
                Driving Lessons', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'course_description',
            [
                'label' => esc_html__('Course Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description', 'drvngsupport'),
            ]
        );


        $repeater->add_control(
            'price_title',
            [
                'label' => esc_html__('Price Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Starts form', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'price',
            [
                'label' => esc_html__('Price', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('$45 - $170', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'course_details',
            [
                'label' => esc_html__('Course Details', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $section_class = $settings["section_class"];
        $title_alignment = $settings["title_alignment"];
        $title_color = $settings["title_color"];
        $title = $settings["title"];
        $sub_title = $settings["sub_title"];

?>
       
    <!-- Courses section -->
    <section class="courses-section <?php echo $section_class; ?>">
        <div class="auto-container">
            <div class="sec-title <?php echo $title_alignment; ?> <?php echo $title_color; ?>">
                <h4><?php echo $title; ?></h4>
                <h2><?php echo $sub_title; ?></h2>
            </div>
            <div class="row">
                <!-- Loop -->
                <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $image = ($item["image"]["id"] != "") ? wp_get_attachment_image_url($item["image"]["id"], "full") : $item["image"]["url"];
                    $image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                    $thumb = ($item["thumb"]["id"] != "") ? wp_get_attachment_image_url($item["thumb"]["id"], "full") : $item["thumb"]["url"];
                    $thumb_alt = get_post_meta($item["thumb"]["id"], "_wp_attachment_image_alt", true);
                    $name = $item["name"];
                    $designation = $item["designation"];
                    $course_title = $item["course_title"];
                    $course_description = $item["course_description"];
                    $price_title = $item["price_title"];
                    $price = $item["price"];
                    $course_details = $item["course_details"]["url"];
                    $course_details_external = $item["course_details"]["is_external"] ? 'target="_blank"' : '';
                    $course_details_nofollow = $item["course_details"]["nofollow"] ? 'rel="nofollow"' : '';
                ?>
                <div class="col-lg-4 course-block-one">
                    <div class="inner-box wow fadeInUp" data-wow-duration="1500ms">
                        <div class="image">
                            <?php
                            if (wp_http_validate_url($image)) {
                            ?>
                                <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                            <?php
                            } else {
                                echo $image;
                            }
                            ?>
                        </div>
                        <div class="lower-content">
                            <div class="instructor-thumb">
                                <?php
                                if (wp_http_validate_url($thumb)) {
                                ?>
                                    <img src="<?php echo esc_url($thumb); ?>" alt="<?php esc_url($thumb_alt); ?>">
                                <?php
                                } else {
                                    echo $thumb;
                                }
                                ?>
                            </div>
                            <div class="designation"><?php echo $designation; ?></div>
                            <div class="name"><?php echo $name; ?></div>
                            <h3><a href="highway-drive.html"><?php echo $course_title; ?></a></h3>
                            <div class="text"><?php echo $course_description; ?></div>
                            <div class="link-btn"><a href="#" class="btn-style-two"><?php echo $price_title; ?> <span><?php echo $price; ?></span></a></div>
                        </div>
                    </div>
                </div>
                <?php $i++;
                } ?>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_courses_Widget() );