<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_cta_three_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_cta_three';
	}

	public function get_title() {
		return __( 'Cta three', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'cta_three' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'button_title',
            [
                'label' => esc_html__('Button Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $button_title = $settings["button_title"];
        $button_link = $settings["button_link"]["url"];
        $button_link_external = $settings["button_link"]["is_external"] ? 'target="_blank"' : '';
        $button_link_nofollow = $settings["button_link"]["nofollow"] ? 'rel="nofollow"' : '';
        $bg_image = ($settings["bg_image"]["id"] != "") ? wp_get_attachment_image_url($settings["bg_image"]["id"], "full") : $settings["bg_image"]["url"];
       

?>
    <!-- cta two -->
    <section class="cta-two" style="background-image: url(<?php echo $bg_image; ?>);">
        <div class="auto-container">
            <h4><?php echo $title; ?></h4>
            <div class="link-btn"><a href="<?php echo esc_url($button_link); ?>"<?php echo $button_link_external; ?> <?php echo $button_link_nofollow; ?> class="theme-btn btn-style-one"><?php echo $button_title; ?></a></div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_cta_three_Widget() );