<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_cta_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_cta';
	}

	public function get_title() {
		return __( 'Cta', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'cta' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'icon',
            [
                'label' => esc_html__('Phone Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );
        $this->add_control(
            'phone_title',
            [
                'label' => esc_html__('Phone Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__('Phone Number', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'phone_tel',
            [
                'label' => esc_html__('Phone Tel', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );	

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $icon = $settings["icon"];
        $phone_number = $settings["phone_number"];
        $phone_tel = $settings["phone_tel"];
        $phone_title = $settings["phone_title"];
        $bg_image = ($settings["bg_image"]["id"] != "") ? wp_get_attachment_image_url($settings["bg_image"]["id"], "full") : $settings["bg_image"]["url"];
?>
       


    <section class="cta-wrapper">
        <div class="container">
            <div class="cta-content bg-cover" style="background-image: url(<?php echo $bg_image; ?>)">
                <div class="row align-items-center">
                    <div class="col-xl-7 pl-xl-3 col-12 text-center text-xl-left">
                        <h1 class="cta-heading"><?php echo $title; ?></h1>
                    </div>
                    <div class="col-xl-4 pl-xl-0 mt-4 mt-xl-0 col-12 text-center text-xl-left">
                        <div class="contact-info">
                            <div class="icon">
                                <i class="<?php echo $icon['value']; ?>"></i>
                            </div>
                            <div class="contact-number">
                                <a href="<?php echo $phone_tel; ?>"><?php echo $phone_number; ?></a>
                                <span><?php echo $phone_title; ?></span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>  

        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_cta_Widget() );