<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_experience_two_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_experience_two';
	}

	public function get_title() {
		return __( 'Experience two', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'experience' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

  
        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('We’ve Great Experience_two
                of Driving', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Get to Know More', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'text',
            [
                'label' => esc_html__('Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Lorem ipsum is are many variations of pass of norms and guide an simply free.', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        

        $this->end_controls_section();

      

        $this->start_controls_section(
			'skills',
			[
				'label' => __( 'Skills', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'skill_title',
            [
                'label' => esc_html__('Skill Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'skill_percent',
            [
                'label' => esc_html__('Skill Percent', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
            ]
        );


        $this->add_control(
            'items2',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $text = $settings["text"];
        $description = $settings["description"];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);


?>
       
 

     <!-- experience section -->
     <section class="experience-section style-two">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6">
                    <div class="image clearfix">
                    <?php
                        if (wp_http_validate_url($image)) {
                        ?>
                            <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                        <?php
                        } else {
                            echo $image;
                        }
                        ?>
                    </div>
                </div>
                <div class="col-lg-6">
                    <div class="sec-title">
                        <h4><?php echo $sub_title; ?></h4>
                        <h2><?php echo $title; ?></h2> 
                        <div class="text-one"><?php echo $text; ?></div>  
                    </div>
                    <div class="text-two"><?php echo $description; ?></div>

                    <div class="progress-levels">
                    <?php
                        $i = 1;
                        foreach ($settings["items2"] as $item2) {
                            $skill_title = $item2["skill_title"];
                            $skill_percent = $item2["skill_percent"];
                        ?>
                        <!--Skill Box-->
                        <div class="progress-box wow fadeIn" data-wow-delay="100ms" data-wow-duration="1500ms">
                            <h5><?php echo $skill_title; ?></h5>
                            <div class="inner">
                                <div class="bar">
                                    <div class="bar-innner"><div class="bar-fill" data-percent="<?php echo $skill_percent; ?>"><div class="percent"></div></div></div>
                                </div>
                            </div>
                        </div>
                        <?php $i++;
                        } ?>
                    </div>
                </div>
            </div> 
        </div>
    </section>

        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_experience_two_Widget() );