<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_faq_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_faq';
	}

	public function get_title() {
		return __( 'Faq', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'faq' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		
        $this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Author Thumb', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'image2',
            [
                'label' => esc_html__('Author Thumb', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'image3',
            [
                'label' => esc_html__('Author Thumb', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_control(
            'image4',
            [
                'label' => esc_html__('Map', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();
		$this->start_controls_section(
			'accordion',
			[
				'label' => __( 'Accordion', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Description', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings['title'];
        $sub_title = $settings['sub_title'];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image2 = ($settings["image2"]["id"] != "") ? wp_get_attachment_image_url($settings["image2"]["id"], "full") : $settings["image2"]["url"];
        $image3 = ($settings["image3"]["id"] != "") ? wp_get_attachment_image_url($settings["image3"]["id"], "full") : $settings["image3"]["url"];
        $image4 = ($settings["image4"]["id"] != "") ? wp_get_attachment_image_url($settings["image4"]["id"], "full") : $settings["image4"]["url"];
        $image4_alt = get_post_meta($settings["image4"]["id"], "_wp_attachment_image_alt", true);

?>
       
    
    

    <section class="faq-section section-padding">
        <div class="container">
            <div class="row">
                <div class="col-xl-6 col-12">
                    <div class="content-block">
                        <p><?php echo $sub_title; ?></p>
                        <h1><?php echo $title; ?></h1>
                        <div class="bg-img">
                            <?php
                            if (wp_http_validate_url($image4)) {
                            ?>
                                <img src="<?php echo esc_url($image4); ?>" alt="<?php esc_url($image4_alt); ?>">
                            <?php
                            } else {
                                echo $image4;
                            }
                            ?>
                            <div class="man bg-cover man-1" style="background-image: url(<?php echo $image; ?>)"></div>
                            <div class="man bg-cover man-2" style="background-image: url(<?php echo $image2; ?>)"></div>
                            <div class="man bg-cover man-3" style="background-image: url(<?php echo $image3; ?>)"></div>
                        </div>
                    </div>
                </div>
                <div class="col-xl-6 col-12 mt-4 mt-xl-0">
                    <div class="faq-content">
                        <div class="faq-accordion">
                            <div id="accordion" class="accordion">
                                <div class="card">
                                    <div class="card-header" id="faq1">
                                        <p class="mb-0 text-capitalize">
                                            <a class="collapsed" role="button" data-toggle="collapse" aria-expanded="false" href="#faq-1">
                                            How do we manage quality assurance?
                                            </a>
                                        </p>
                                    </div>
                                    <div id="faq-1" class="collapse" data-parent="#accordion">
                                        <div class="card-body">
                                            Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec rhoncus dolor at libero ultricies ullamcorper vel ut dui. Maecenas sollicitudin risus non faucibus blandit. Nulla facilisi. 
                                        </div>
                                    </div>
                                </div> <!-- /card -->
                                <div class="card">
                                    <div class="card-header" id="faq2">
                                        <p class="mb-0 text-capitalize">
                                            <a class="collapsed" role="button" data-toggle="collapse" aria-expanded="true" href="#faq-2">With diverse capabilities and extensive manufacturing?
                                            </a>
                                        </p>
                                    </div>
                                    <div id="faq-2" class="collapse show" data-parent="#accordion">
                                        <div class="card-body">
                                            We’re proud of our reputation as one of the finest “one-call, one-stop” of brand identity and electronic user interface products. We take your trust seriously, employing proven quality management principles to enhance customer satisfaction and continually improve.
                                        </div>
                                    </div>
                                </div> <!-- /card -->
                            </div>                        
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_faq_Widget() );