<?php

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_introduction_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_introduction';
	}

	public function get_title() {
		return __( 'introduction', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'introduction' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'text',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'text_two',
            [
                'label' => esc_html__('Phone Number Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__('Phone Number', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'phone_number_tel',
            [
                'label' => esc_html__('Phone Number Tel', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'icon',
            [
                'label' => esc_html__('Phone Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
               
            ]
        );



        $this->add_control(
            'image',
            [
                'label' => esc_html__('Features Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image2',
            [
                'label' => esc_html__('Author Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image3',
            [
                'label' => esc_html__('Signature', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $repeater = new Repeater();

		$repeater->add_control(
            'list_item',
            [
                'label' => esc_html__('List', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
        $image2 = ($settings["image2"]["id"] != "") ? wp_get_attachment_image_url($settings["image2"]["id"], "full") : $settings["image2"]["url"];
        $image2_alt = get_post_meta($settings["image2"]["id"], "_wp_attachment_image2_alt", true);
        $image3 = ($settings["image3"]["id"] != "") ? wp_get_attachment_image_url($settings["image3"]["id"], "full") : $settings["image3"]["url"];
        $image3_alt = get_post_meta($settings["image3"]["id"], "_wp_attachment_image3_alt", true);

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $text = $settings["text"];
        $icon = $settings["icon"];
        $text_two = $settings["text_two"];
        $phone_number = $settings["phone_number"];
        $phone_number_tel = $settings["phone_number_tel"];

?>
       
    <!-- Introduction Section -->
    <section class="introduction-section">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6">
                    <div class="image"><div class="img_hover_3">
                    <?php
                    if (wp_http_validate_url($image)) {
                    ?>
                        <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                    <?php
                    } else {
                        echo $image;
                    }
                    ?>
                    </div></div>
                </div>
                <div class="col-lg-6">
                    <div class="sec-title mb-30">
                    <h4><?php echo $sub_title; ?></h4>
                    <h2><?php echo $title; ?></h2>
                    </div>
                    <div class="text mb-30"><?php echo $text; ?></div>
                    <div class="row">
                        <div class="col-md-7">
                            <div class="ul">
                            <?php
                            $i = 1;
                            foreach ($settings["items"] as $item) {
                                $list_item = $item["list_item"];
                                
                            ?>
                                <li><i class="fas fa-arrow-circle-right"></i><?php echo $list_item; ?></li>
                            <?php $i++;
                            } ?>
                            </div>
                            <div class="image-wrapper">
                                <div class="image-two">
                                <?php
                                if (wp_http_validate_url($image2)) {
                                ?>
                                    <img src="<?php echo esc_url($image2); ?>" alt="<?php esc_url($image2_alt); ?>">
                                <?php
                                } else {
                                    echo $image2;
                                }
                                ?>
                                </div>
                                <div class="signature">
                                <?php
                                if (wp_http_validate_url($image3)) {
                                ?>
                                    <img src="<?php echo esc_url($image3); ?>" alt="<?php esc_url($image3_alt); ?>">
                                <?php
                                } else {
                                    echo $image3;
                                }
                                ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-5">
                            <div class="text-box">
                                <div class="icon"><i class="<?php echo $icon['value']; ?>"></i></div>
                                <div class="text-two"><?php echo $text_two; ?></div>
                                <a href="tel:<?php echo $phone_number_tel; ?>"><?php echo $phone_number; ?></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>



        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_introduction_Widget() );