<?php


use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_main_slider_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_main_slider';
	}

	public function get_title() {
		return __( 'Main Slider', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'slider' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
			'layout_style',
			[
				'label' => __( 'Layout Style', 'drvngsupport' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'Default',
				'options' => [
					'default'  => __( 'Default', 'drvngsupport' ),
                    'style-two' => __( 'Style Two', 'drvngsupport' ),
				],
			]
		);

        $repeater = new Repeater();


		$repeater->add_control(
            'sub_heading',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'heading',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'background_image',
            [
                'label' => esc_html__('Background Shape', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'button_title',
            [
                'label' => esc_html__('Button Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );
        

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();
        $layout_style = $settings["layout_style"];

?>



    <!-- Bnner Section -->
    <section class="banner-section">
        <div class="swiper-container banner-slider">
            <div class="swiper-wrapper">
            <?php
            $i = 1;
            foreach ($settings["items"] as $item) {
                $background_image = ($item["background_image"]["id"] != "") ? wp_get_attachment_image_url($item["background_image"]["id"], "full") : $item["background_image"]["url"];
                $sub_heading = $item['sub_heading'];
                $heading = $item['heading'];
                $button_title = $item["button_title"];
                $button_link = $item["button_link"]["url"];
                $button_link_external = $item["button_link"]["is_external"] ? 'target="_blank"' : '';
                $button_link_nofollow = $item["button_link"]["nofollow"] ? 'rel="nofollow"' : '';
            ?>
                <!-- Slide Item -->
                <div class="swiper-slide" style="background-image: url(<?php echo $background_image ;?>);">
                    <div class="content-outer">
                        <div class="content-box justify-content-center">
                            <div class="inner text-center">
                                <h4><?php echo $sub_heading; ?></h4>
                                <h1><?php echo $heading; ?></h1>
                                <div class="link-box">
                                    <a href="<?php echo esc_url($button_link); ?>" <?php echo $button_link_external; ?> <?php echo $button_link_nofollow; ?> class="theme-btn btn-style-one"><span><?php echo $button_title; ?></span></a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php $i++;
            } ?>
            </div>
        </div>
        <div class="banner-slider-nav">
            <div class="banner-slider-control banner-slider-button-prev"><span><i class="flaticon-right-arrow-4"></i></span></div>
            <div class="banner-slider-control banner-slider-button-next"><span><i class="flaticon-right-arrow-4"></i></span> </div>
        </div>
    </section>
    <!-- End Bnner Section -->



        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_main_slider_Widget() );