<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_news_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_news';
	}

	public function get_title() {
		return __( 'News', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'news' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	private function get_blog_categories() {
        $options = array();
        $taxonomy = 'category';
        if (!empty($taxonomy)) {
            $terms = get_terms(
                array(
                    'parent' => 0,
                    'taxonomy' => $taxonomy,
                    'hide_empty' => false,
                )
            );
            if (!empty($terms)) {
                foreach ($terms as $term) {
                    if (isset($term)) {
                        $options[''] = 'Select';
                        if (isset($term->slug) && isset($term->name)) {
                            $options[$term->slug] = $term->name;
                        }
                    }
                }
            }
        }
        return $options;
    }

	protected function _register_controls() {
		$this->start_controls_section(
			'recent_posts',
			[
				'label' => __( 'Posts Settings', 'koronasupport' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('News & Articles', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Direct from Blog', 'drvngsupport'),
            ]
        );
		$this->add_control(
            'number', [
            'label' => esc_html__('Number of Post', 'koronasupport'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'min'     => 3,
				'max'     => 100,
				'default' => 3,
            ]
        );
		$this->add_control(
            'category_id', [
                'type' => \Elementor\Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'koronasupport'),
                'options' => $this->get_blog_categories()
            ]
        );

        $this->add_control(
            'order_by', [
                'label' => esc_html__('Order By', 'koronasupport'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('Date', 'koronasupport'),
                    'ID' => esc_html__('ID', 'koronasupport'),
                    'author' => esc_html__('Author', 'koronasupport'),
                    'title' => esc_html__('Title', 'koronasupport'),
                    'modified' => esc_html__('Modified', 'koronasupport'),
                    'rand' => esc_html__('Random', 'koronasupport'),
                    'comment_count' => esc_html__('Comment count', 'koronasupport'),
                    'menu_order' => esc_html__('Menu order', 'koronasupport')
                ]
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__('Order', 'koronasupport'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('DESC', 'koronasupport'),
                    'asc' => esc_html__('ASC', 'koronasupport')
                ]
            ]
        );

		$this->end_controls_section();
	}

	protected function render() {
			global $plugin_root;
            $settings = $this->get_settings_for_display();
            $title = $settings["title"];
            $sub_title = $settings["sub_title"];
			$settings = $this->get_settings_for_display();
			$posts_per_page = $settings['number'];
			$order_by = $settings['order_by'];
	        $order = $settings['order'];
	        $pg_num = get_query_var('paged') ? get_query_var('paged') : 1;
	        $args = array(
	            'post_type' => array('post'),
	            'post_status' => array('publish'),
	            'nopaging' => false,
	            'paged' => $pg_num,
	            'posts_per_page' => $posts_per_page,
	            'category_name' => $settings['category_id'],
	            'orderby' => $order_by,
	            'order' => $order,
	        );
	        $query = new \WP_Query($args);

	        ?>

        <!-- News Section -->
        <section class="news-section">
            <div class="auto-container">
                <div class="sec-title text-center">
                    <h4><?php echo $sub_title; ?></h4>
                    <h2><?php echo $title; ?></h2>
                </div>
                <div class="row">
                <?php
                    $i = 0;
                    if ($query->have_posts()) {
                        while ($query->have_posts()) {
                            $query->the_post();
                            ?>
                    <div class="col-lg-4 news-block-one">
                        <div class="inner-box wow fadeInUp" data-wow-duration="1500ms">
                            <div class="image"><?php the_post_thumbnail(); ?></div>
                            <div class="lower-content">
                                <div class="read-more">
                                    <a href="<?php get_the_permalink(); ?>"><i class="fas fa-long-arrow-alt-right"></i></a>
                                </div>
                                <h4><a href="<?php echo esc_url( get_permalink() ); ?>"><?php the_title(); ?></a></h4>
                                <div class="text"><?php
										$content = substr( get_the_excerpt(), 0, 50 );
										echo esc_html( $content ) . '...';
										?></div>
                                <ul class="post-mate">
                                    <li><i class="far fa-clock"></i> <?php drvng_posted_on(); ?> </li>
                                    <li><i class="far fa-user"></i> <?php echo esc_html__( 'By', 'drvngsupport' ); ?> <?php echo get_the_author(); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php
                    $i++;
                }
                wp_reset_postdata();
            }
            ?>
                </div>
            </div>
        </section>

		
		<?php
	}
	protected function content_template() {
                    
    }
}


// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_news_Widget() );