<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_pricing_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_pricing';
	}

	public function get_title() {
		return __( 'Pricing', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'pricing' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'title_css_class',
            [
                'label' => esc_html__('Title css class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        

        $this->end_controls_section();

        $this->start_controls_section(
			'pricing',
			[
				'label' => __( 'Pricing', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'price_title',
            [
                'label' => esc_html__('Price Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
            ]
        );

		$repeater->add_control(
            'category',
            [
                'label' => esc_html__('Category', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'price',
            [
                'label' => esc_html__('Price', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'pricing_list',
            [
                'label' => esc_html__('Pricing List', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'button_title',
            [
                'label' => esc_html__('Button Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );


        $repeater->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );

        $repeater->add_control(
            'active',
            [
                'label' => esc_html__('Active Status', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $title_css_class = $settings["title_css_class"];

?>
       


    <!-- Our Pricing -->
    <section class="pricing-section">
        <div class="auto-container">
            <div class="sec-title text-center <?php echo $title_css_class; ?>">
                <h4><?php echo $sub_title; ?></h4>
                <h2><?php echo $title; ?></h2>
            </div>
            <div class="row">
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $active = $item["active"];
                    $price_title = $item["price_title"];
                    $icon = $item["icon"];
                    $category = $item["category"];
                    $price = $item["price"];
                    $pricing_list = $item["pricing_list"];
                    $button_title = $item["button_title"];
                    $button_link = $item["button_link"]["url"];
                    $button_link_external = $item["button_link"]["is_external"] ? 'target="_blank"' : '';
                    $button_link_nofollow = $item["button_link"]["nofollow"] ? 'rel="nofollow"' : '';
                ?>
                <div class="col-lg-4 pricing-block <?php echo $active; ?>">
                    <div class="inner-box wow fadeInDown" data-wow-duration="1500ms">
                        <div class="icon"><i class="<?php echo $icon['value']; ?>"></i></div>
                        <h3><?php echo $price_title; ?></h3>
                        <div class="category">
                            <h4><?php echo $category; ?></h4>
                            <div class="price"><?php echo $price; ?></div>
                        </div>
                        <ul>
                            <?php echo $pricing_list; ?>
                        </ul>
                        <div class="link-btn"><a href="<?php echo esc_url($button_link); ?>" <?php echo $button_link_external; ?> <?php echo $button_link_nofollow; ?> class="btn-style-one"><?php echo $button_title; ?></a></div>
                    </div>
                </div>
                <?php $i++;
                } ?>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_pricing_Widget() );