<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_project_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_project';
	}

	public function get_title() {
		return __( 'Project', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'project' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {

       
        $this->start_controls_section(
			'project',
			[
				'label' => __( 'Project', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'cat',
            [
                'label' => esc_html__('Project Category', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'ctitle',
            [
                'label' => esc_html__('Client', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'name',
            [
                'label' => esc_html__('Client Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__('Price Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'project_details',
            [
                'label' => esc_html__('Project Details', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );

        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );


        $repeater->add_control(
            'price',
            [
                'label' => esc_html__('Price', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('$45 - $170', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'course_details',
            [
                'label' => esc_html__('Course Details', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],

            ]
        );
        $repeater->add_control(
            'button_title',
            [
                'label' => esc_html__('Button Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Learn More', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'button_link',
            [
                'label' => esc_html__('Button Link', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );
        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();


?>
       
    <!-- project section -->
    <section class="project-section <?php echo $section_class; ?>">
        <div class="auto-container">
            <div class="sec-title <?php echo $title_alignment; ?> <?php echo $title_color; ?>">
                <h4><?php echo $title; ?></h4>
                <h2><?php echo $sub_title; ?></h2>
            </div>
            <div class="row">
                <!-- Loop -->
                <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $image = ($item["image"]["id"] != "") ? wp_get_attachment_image_url($item["image"]["id"], "full") : $item["image"]["url"];
                    $image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                    $thumb = ($item["thumb"]["id"] != "") ? wp_get_attachment_image_url($item["thumb"]["id"], "full") : $item["thumb"]["url"];
                    $thumb_alt = get_post_meta($item["thumb"]["id"], "_wp_attachment_image_alt", true);
                    $name = $item["name"];
                    $designation = $item["designation"];
                    $course_title = $item["course_title"];
                    $course_description = $item["course_description"];
                    $price_title = $item["price_title"];
                    $price = $item["price"];
                    $course_details = $item["course_details"]["url"];
                    $course_details_external = $item["course_details"]["is_external"] ? 'target="_blank"' : '';
                    $course_details_nofollow = $item["course_details"]["nofollow"] ? 'rel="nofollow"' : '';
                    $course_details = $item["course_details"]["url"];
                    $course_details_external = $item["course_details"]["is_external"] ? 'target="_blank"' : '';
                    $course_details_nofollow = $item["course_details"]["nofollow"] ? 'rel="nofollow"' : '';
                ?>
                <div class="col-lg-4 course-block-one">
                    <div class="inner-box wow fadeInUp" data-wow-duration="1500ms">
                        <div class="image">
                            <?php
                            if (wp_http_validate_url($image)) {
                            ?>
                                <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                            <?php
                            } else {
                                echo $image;
                            }
                            ?>
                        </div>
                        <div class="lower-content">
                            <div class="instructor-thumb">
                                <?php
                                if (wp_http_validate_url($thumb)) {
                                ?>
                                    <img src="<?php echo esc_url($thumb); ?>" alt="<?php esc_url($thumb_alt); ?>">
                                <?php
                                } else {
                                    echo $thumb;
                                }
                                ?>
                            </div>
                            <div class="designation"><?php echo $designation; ?></div>
                            <div class="name"><?php echo $name; ?></div>
                            <h3><a href="highway-drive.html"><?php echo $course_title; ?></a></h3>
                            <div class="text"><?php echo $course_description; ?></div>
                            <div class="link-btn"><a href="#" class="btn-style-two"><?php echo $price_title; ?> <span><?php echo $price; ?></span></a></div>
                        </div>
                    </div>
                </div>
                <?php $i++;
                } ?>
            </div>
        </div>
    </section>

    <section class="portfolio-section section-padding pt-0">
        <div class="container">
            <div class="project-wrapper">
                <div class="portfolio-carousel-active owl-carousel">
                <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $image = ($item["image"]["id"] != "") ? wp_get_attachment_image_url($item["image"]["id"], "full") : $item["image"]["url"];
                    $image_alt = get_post_meta($item["image"]["id"], "_wp_attachment_image_alt", true);
                    $title = $item["title"];
                    $cat = $item["cat"];
                    $ctitle = $item["ctitle"];
                    $name = $item["name"];
                    $description = $item["description"];
                    $button_title = $item["button_title"];
                    $button_link = $item["button_link"]["url"];
                    $button_link_external = $item["button_link"]["is_external"] ? 'target="_blank"' : '';
                    $button_link_nofollow = $item["button_link"]["nofollow"] ? 'rel="nofollow"' : '';
                ?>
                    <div class="single-project">
                        <div class="project-contents">
                            <div class="row">
                                <div class="project-details col-lg-4 offset-lg-1 pl-lg-0 order-2 order-lg-1 col-12">
                                    <div class="project-meta">
                                        <a href="#" class="project-cat"><?php echo $cat; ?></a>
                                        <div class="client-info d-inline">
                                            <span><i class="fal fa-user"></i> <?php echo $ctitle; ?>:</span> <?php echo $name; ?>
                                        </div>
                                    </div>
                                    <h2><?php echo $designation; ?></h2>
                                    <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliqui</p>
                                    <a href="project-details.html" class="read-btn theme-btn">Case Details <i class="fal fa-long-arrow-right"></i></a>
                                </div>
                                <div class="project-thumbnail col-lg-5 offset-lg-1 p-lg-0 order-1 order-lg-2 col-12">
                                    <a href="assets/img/project/project1.jpg" class="popup-gallery bg-cover" style="background-image: url('assets/img/project/project1.jpg')"></a>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php $i++;
                } ?>
                </div>

                <div class="project-carousel-nav"></div>
            </div>
        </div>
    </section>  


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_project_Widget() );