<?php

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_services_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_services';
	}

	public function get_title() {
		return __( 'Services', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'services' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'video_title',
            [
                'label' => esc_html__('Video Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
        
        
        
        $this->end_controls_section();

        $this->start_controls_section(
			'services',
			[
				'label' => __( 'Services', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
            'video_url',
            [
                'label' => esc_html__('Video Url', 'drvngsupport'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'drvngsupport'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );

        $repeater = new Repeater();

		$repeater->add_control(
            'service_title',
            [
                'label' => esc_html__('Service Title', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'service_text',
            [
                'label' => esc_html__('Service Text', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::ICONS,
                
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $video_title = $settings["video_title"];
        $video_url = $settings["video_url"]["url"];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];

?>
       
    <section class="service-section" style="background-image: url(<?php echo $image; ?>);">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-8">
                    <div class="sec-title light">
                        <h4><?php echo $sub_title; ?></h4>
                        <h2><?php echo $title; ?></h2>
                    </div>
                </div>
                <div class="col-lg-4">
                    <div class="video-box">
                        <div class="video-btn"><a href="<?php echo $video_url; ?>" class="overlay-link play-now ripple" data-fancybox="gallery" data-caption=""><i class="flaticon-play-button"></i></a></div>
                        <h4><?php echo $video_title; ?></h4>
                    </div>
                </div>
            </div>
            <div class="divider"></div>
            <div class="row">
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $icon = $item["icon"];
                    $service_title = $item["service_title"];
                    $service_text = $item["service_text"];
                    
                ?>
                <div class="col-lg-4 service-block-1">
                    <div class="icon_box wow fadeInUp" data-wow-duration="1500ms">
                        <div class="icon"><i class="<?php echo $icon['value']; ?>"></i></div>
                        <h4><?php echo $service_title; ?></h4>
                    </div>
                    <div class="text">
                    <?php echo $service_text; ?>.
                    </div>
                </div>
                <?php $i++;
            } ?>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_services_Widget() );