<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_team_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_team';
	}

	public function get_title() {
		return __( 'Team', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'team' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'section_class',
            [
                'label' => esc_html__('Section Class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('We Help Students to Pass <br>Test & Get a License on the <br>First Try', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Ready to Learn Driving?', 'drvngsupport'),
            ]
        );
        
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'title_class',
            [
                'label' => esc_html__('Title Class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        

        $this->end_controls_section();

        $this->start_controls_section(
			'team',
			[
				'label' => __( 'Team', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();

		$repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'designation',
            [
                'label' => esc_html__('Designation', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

		$repeater->add_control(
            'social_icon',
            [
                'label' => esc_html__('Social Icon', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'author_thumb',
            [
                'label' => esc_html__('Author Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $bg_image = ($settings["bg_image"]["id"] != "") ? wp_get_attachment_image_url($settings["bg_image"]["id"], "full") : $settings["bg_image"]["url"];
        $section_class = $settings["section_class"];
        $title_class = $settings["title_class"];

?>
       
    <!-- Our Team Section -->
    <section class="our-team-section <?php echo $section_class; ?>">
        <div class="shape" style="background-image: url(<?php echo $bg_image; ?>)"></div>
        <div class="auto-container">
            <div class="sec-title text-center <?php echo $title_class; ?>">
                <h4><?php echo $sub_title; ?></h4>
                <h2><?php echo $title; ?></h2>
            </div>
            <div class="row">
                <?php
                    $i = 1;
                    foreach ($settings["items"] as $item) {
                    $name = $item["name"];
                    $designation = $item["designation"];
                    $social_icon = $item["social_icon"];
                    $author_thumb = ($item["author_thumb"]["id"] != "") ? wp_get_attachment_image_url($item["author_thumb"]["id"], "full") : $item["author_thumb"]["url"];
                    $author_thumb_alt = get_post_meta($item["author_thumb"]["id"], "_wp_attachment_image_alt", true);
                ?>  
                <div class="col-lg-3 col-md-6 team-block-one">
                    <div class="inner-box wow fadeInUp" data-wow-duration="1500ms">
                        <div class="image img_hover_3">
                        <?php
                        if (wp_http_validate_url($author_thumb)) {
                        ?>
                            <img src="<?php echo esc_url($author_thumb); ?>" alt="<?php esc_url($author_thumb_alt); ?>">
                        <?php
                        } else {
                            echo $author_thumb;
                        }
                        ?>
                        </div>
                        <div class="lower-content">
                            <div class="name"><?php echo $name; ?></div>
                            <div class="designation"><?php echo $designation; ?></div>
                            <ul class="social-links">
                                <?php echo $social_icon; ?>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php $i++; } ?>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_team_Widget() );