<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_testimonials_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_testimonials';
	}

	public function get_title() {
		return __( 'Testimonials', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'testimonials' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'section_class',
            [
                'label' => esc_html__('Section Class', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('What They’re Saying First Try', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Company Feedbacks', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'Testimonials',
			[
				'label' => __( 'Testimonials', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $repeater = new Repeater();
        
        $repeater->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Lorem Ipsum', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('David Cooper', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'designation',
            [
                'label' => esc_html__('Designation', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('Designation', 'drvngsupport'),
            ]
        );

        $repeater->add_control(
            'thumb',
            [
                'label' => esc_html__('Thumb Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->add_control(
            'items',
            [
                'label' => esc_html__('Repeater List', 'drvngsupport'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__('Title #1', 'drvngsupport'),
                        'list_content' => esc_html__('Item content. Click the edit button to change this text.', 'drvngsupport'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $bg_image = ($settings["bg_image"]["id"] != "") ? wp_get_attachment_image_url($settings["bg_image"]["id"], "full") : $settings["bg_image"]["url"];
        $section_class = $settings["section_class"];
?>
       
    <!--Testimonials Section-->
    <section class="testimonials-section <?php echo $section_class; ?>" style="background-image: url(<?php echo $bg_image; ?>)">
        <div class="auto-container">
            <div class="sec-title text-center">
                <h4><?php echo $sub_title; ?></h4>
                <h2><?php echo $title; ?></h2>
            </div>
            <div class="theme_carousel owl-theme owl-carousel" data-options='{"loop": true, "center": false, "margin": 30, "autoheight":true, "lazyload":true, "nav": true, "dots": true, "autoplay": true, "autoplayTimeout": 6000, "smartSpeed": 1000, "responsive":{ "0" :{ "items": "1" }, "480" :{ "items" : "1" }, "600" :{ "items" : "2" }, "768" :{ "items" : "2" } , "992":{ "items" : "3" }, "1200":{ "items" : "3" }}}'>
            <?php
                $i = 1;
                foreach ($settings["items"] as $item) {
                    $description = $item["description"];
                    $name = $item["name"];
                    $designation = $item["designation"];
                    $thumb = ($item["thumb"]["id"] != "") ? wp_get_attachment_image_url($item["thumb"]["id"], "full") : $item["thumb"]["url"];
                    $thumb_alt = get_post_meta($item["thumb"]["id"], "_wp_attachment_image_alt", true);
                ?>
                <div class="testimonials-block-one">
                    <div class="inner-box">
                        <div class="text"><?php echo $description; ?></div>                    
                        <div class="author-info">
                            <div class="image">
                            <?php
                                if (wp_http_validate_url($thumb)) {
                                ?>
                                    <img src="<?php echo esc_url($thumb); ?>" alt="<?php esc_url($thumb_alt); ?>">
                                <?php
                                } else {
                                    echo $thumb;
                                }
                            ?>
                            </div>
                            <div class="name"><?php echo $name; ?></div>
                            <div class="designation"><?php echo $designation; ?></div>
                        </div>
                    </div>
                </div>
                <?php $i++;
            } ?>
            </div>
        </div>  
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_testimonials_Widget() );