<?php
/**
 * drvng Feature Box Two
 */

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class drvng_why_choose_us_Widget extends \Elementor\Widget_Base {
	public function get_name() {
		return 'drvng_why_choose_us';
	}

	public function get_title() {
		return __( 'Why choose us', 'drvngsupport' );
	}

	public function get_icon() {
		return 'drvng-widget-ico';
	}

	public function get_keywords() {
		return [ 'drvng', 'why_choose_us' ];
	}

	public function get_categories() {
		return [ 'drvng_category' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'general',
			[
				'label' => __( 'General', 'drvngsupport' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );
        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Heading', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => esc_html__('List', 'drvngsupport'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('', 'drvngsupport'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'drvngsupport'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );
    

        $this->end_controls_section();
	}

	protected function render() {
		global $plugin_root;
		$settings = $this->get_settings_for_display();

        $title = $settings["title"];
        $sub_title = $settings["sub_title"];
        $description = $settings["description"];
        $list = $settings["list"];
        $image = ($settings["image"]["id"] != "") ? wp_get_attachment_image_url($settings["image"]["id"], "full") : $settings["image"]["url"];
        $image_alt = get_post_meta($settings["image"]["id"], "_wp_attachment_image_alt", true);
        $shape = ($settings["shape"]["id"] != "") ? wp_get_attachment_image_url($settings["shape"]["id"], "full") : $settings["shape"]["url"];
        $shape_alt = get_post_meta($settings["shape"]["id"], "_wp_attachment_image_alt", true);

?>
       

    <!-- Why Choose Section -->
    <section class="why-choose-section pt-0">
        <div class="auto-container">
            <div class="row">
                <div class="col-lg-6">
                    <div class="sec-title">
                        <h4><?php echo $sub_title; ?></h4>
                        <h2><?php echo $title; ?></h2>
                    </div>
                    <div class="text mb-40"><?php echo $description; ?></div>
                    <ul class="list">
                        <?php echo $list; ?>
                    </ul>
                </div>
                <div class="col-lg-6">
                    <div class="image-block">
                        <div class="shape">
                            <?php
                            if (wp_http_validate_url($shape)) {
                            ?>
                                <img src="<?php echo esc_url($shape); ?>" alt="<?php esc_url($shape_alt); ?>">
                            <?php
                            } else {
                                echo $shape;
                            }
                            ?>
                        </div>
                        <div class="image">
                            <div class="img_hover_3">
                                <?php
                                if (wp_http_validate_url($image)) {
                                ?>
                                    <img src="<?php echo esc_url($image); ?>" alt="<?php esc_url($image_alt); ?>">
                                <?php
                                } else {
                                    echo $image;
                                }
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>


        <?php

	}
}

// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new \drvng_why_choose_us_Widget() );