<?php
/**
 * Recent posts widget.
 *
 */

// Adds widget: drvngsupport Recent Posts
class drvngsupport_recent_posts_Widget extends WP_Widget {

	function __construct() {
		parent::__construct(
			'popular_posts',
			esc_html__( 'drvng Recent Posts', 'drvngsupport' ),
			array( 'description' => esc_html__( 'Display list of recent posts with feature image', 'drvngsupport' ) )
		);
	}

	private $widget_fields = array(
		array(
			'label' => 'Number of Posts',
			'id' => 'posts_num',
			'default' => '3',
			'type' => 'number',
		),
	);

	public function widget( $args, $instance ) {
		echo wp_kses_post( $args['before_widget'] );

		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post( $args['before_title'] ) . apply_filters( 'widget_title', $instance['title'] ) . wp_kses_post( $args['after_title'] );
		}
		$post_args = array(
			'posts_per_page' => $instance['posts_num'],
			'post_type'      => 'post',
			'post_status'    => 'publish',
		);
		$recent_posts = new WP_Query( $post_args );
		if ( $recent_posts->have_posts() ){
			while ( $recent_posts->have_posts() ) {
				$recent_posts->the_post();
				?>
				<article class="post">
					<?php if ( has_post_thumbnail() ) : ?>
					<figure class="post-thumb">
						<?php the_post_thumbnail( 'drvng-recent-post-size' ); ?>
					</figure>
					<?php endif; ?>
					<div>
					<div class="post-info"><?php echo get_the_author(); ?></div>
					<div class="text"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
					</div>
					</div>
				</article>
				<?php
			}
		}
		echo wp_kses_post( $args['after_widget'] );
	}

	public function field_generator( $instance ) {
		$output = '';
		foreach ( $this->widget_fields as $widget_field ) {
			$default = '';
			if ( isset( $widget_field['default'] ) ) {
				$default = $widget_field['default'];
			}
			$widget_value = ! empty( $instance[ $widget_field['id'] ] ) ? $instance[ $widget_field['id'] ] : esc_html__( $default, 'drvngsupport' );
			switch ( $widget_field['type'] ) {
				default:
					$output .= '<p>';
					$output .= '<label for="' . esc_attr( $this->get_field_id( $widget_field['id'] ) ) . '">' . esc_attr( $widget_field['label'], 'drvngsupport' ) . ':</label> ';
					$output .= '<input class="widefat" id="' . esc_attr( $this->get_field_id( $widget_field['id'] ) ) . '" name="' . esc_attr( $this->get_field_name( $widget_field['id'] ) ) . '" type="' . $widget_field['type'] . '" value="' . esc_attr( $widget_value ) . '">';
					$output .= '</p>';
			}
		}
		echo $output;
	}

	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'drvngsupport' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php
		$this->field_generator( $instance );
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		foreach ( $this->widget_fields as $widget_field ) {
			switch ( $widget_field['type'] ) {
				default:
					$instance[ $widget_field['id'] ] = ( ! empty( $new_instance[ $widget_field['id'] ] ) ) ? strip_tags( $new_instance[ $widget_field['id'] ] ) : '';
			}
		}
		return $instance;
	}
}
